Subject: [bug#54539] [PATCH v2 23/30] gnu: fontutils: Autoload unless used by Guix.

From: Maxime Devos <[email-masked]>
Date: Sat, 3 Sep 2022 18:43:25 +0200

See first commit in the series for the procedure.
This helps with, but is not sufficient for, avoiding Java.
---
 gnu/packages/fontutils.scm | 71 ++++++++++++++++++++------------------
 1 file changed, 37 insertions(+), 34 deletions(-)

diff --git a/gnu/packages/fontutils.scm b/gnu/packages/fontutils.scm
index da324a6a9d..0257fff32e 100644
--- a/gnu/packages/fontutils.scm
+++ b/gnu/packages/fontutils.scm
@@ -34,40 +34,43 @@
 
 (define-module (gnu packages fontutils)
   #:use-module (gnu packages)
-  #:use-module (gnu packages autotools)
-  #:use-module (gnu packages bison)
-  #:use-module (gnu packages check)
-  #:use-module (gnu packages compression)
-  #:use-module (gnu packages datastructures)
-  #:use-module (gnu packages docbook)
-  #:use-module (gnu packages flex)
-  #:use-module (gnu packages fonts)
-  #:use-module (gnu packages freedesktop)
-  #:use-module (gnu packages fribidi)
-  #:use-module (gnu packages gcc)
-  #:use-module (gnu packages gettext)
-  #:use-module (gnu packages ghostscript)
-  #:use-module (gnu packages glib)
-  #:use-module (gnu packages gnome)
-  #:use-module (gnu packages gperf)
-  #:use-module (gnu packages graphics)
-  #:use-module (gnu packages gtk)
-  #:use-module (gnu packages image)
-  #:use-module (gnu packages java)
-  #:use-module (gnu packages linux)
-  #:use-module (gnu packages man)
-  #:use-module (gnu packages ninja)
-  #:use-module (gnu packages perl)
-  #:use-module (gnu packages pkg-config)
-  #:use-module (gnu packages python)
-  #:use-module (gnu packages python-build)
-  #:use-module (gnu packages python-xyz)
-  #:use-module (gnu packages sqlite)
-  #:use-module (gnu packages webkit)
-  #:use-module (gnu packages xdisorg)
-  #:use-module (gnu packages xml)
-  #:use-module (gnu packages xorg)
-  #:use-module (gnu packages tex)
+  #:use-module (gnu packages autotools) ; required by "guix build -d guix"
+  #:autoload (gnu packages bison) (bison)
+  #:autoload (gnu packages check)
+  (check googletest python-pytest python-pytest-cov python-pytest-randomly
+         python-pytest-runner python-pytest-xdist)
+  #:use-module (gnu packages compression) ; required by "guix build -d guix"
+  #:autoload (gnu packages datastructures) (tllist)
+  #:autoload (gnu packages docbook) (docbook-utils)
+  #:autoload (gnu packages flex) (flex)
+  #:use-module (gnu packages fonts) ; required by "guix build -d guix"
+  #:autoload (gnu packages freedesktop) (desktop-file-utils)
+  #:autoload (gnu packages fribidi) (fribidi)
+  #:use-module (gnu packages gettext) ; required by "guix build -d guix"
+  #:use-module (gnu packages ghostscript) ; required by "guix build -d guix"
+  #:autoload (gnu packages glib) (glib gobject-introspection)
+  #:autoload (gnu packages gnome)
+  (gsettings-desktop-schemas json-glib libsoup-minimal-2 vala-0.52 yelp-tools)
+  #:use-module (gnu packages gperf) ; required by "guix build -d guix"
+  #:autoload (gnu packages graphics) (python-booleanoperations skia)
+  #:use-module (gnu packages gtk) ; required by "guix build -d guix"
+  #:use-module (gnu packages image) ; required by "guix build -d guix"
+  #:autoload (gnu packages java) (java-antlr4-runtime-cpp)
+  #:use-module (gnu packages linux) ; required by "guix build -d guix"
+  #:autoload (gnu packages man) (scdoc)
+  #:autoload (gnu packages ninja) (ninja)
+  #:use-module (gnu packages perl) ; required by "guix build -d guix"
+  #:use-module (gnu packages pkg-config) ; required by "guix build -d guix"
+  #:use-module (gnu packages python) ; required by "guix build -d guix"
+  #:autoload (gnu packages python-build)
+  (python-setuptools-scm python-poetry-core python-pypa-build python-wheel)
+  #:use-module (gnu packages python-xyz) ; required by "guix build -d guix"
+  #:autoload (gnu packages sqlite) (sqlite)
+  #:autoload (gnu packages webkit) (webkitgtk-with-libsoup2)
+  #:autoload (gnu packages xdisorg) (pixman)
+  #:use-module (gnu packages xml) ; required by "guix build -d guix"
+  #:use-module (gnu packages xorg) ; required by "guix build -d guix"
+  #:use-module (gnu packages tex) ; required by "guix build -d guix"
   #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix gexp)
   #:use-module (guix packages)
-- 
2.37.2